# coding: utf-8

"""
    Green Team Clinical API

    The Green Team’s Clinical Data Service API provides defined access to clinical data on ~16,000 ‘HuSH+’ patients with an ‘asthma-like’ phenotype. Users can select input parameters, and the service returns select output based on the input parameters. The input parameters are: age; sex; race; type of visit; and specific ICD and CPT codes1. Based on the input parameters, the service returns the following outpatient parameters: (1) a list of patient IDs and dates of ED and outpatient visits over the 12-month period after diagnosis; and (2) a list of medications prescribed over the 12-month period after diagnosis. The output data are stratified by patients with ≤2 or >2 ED visits over the 12-month period after diagnosis—the primary clinical endpoint used to define, respectively, patients who are ‘responsive’ and ‘non-responsive’ to treatment.

    OpenAPI spec version: 0.0.1
    Contact: champioj@email.unc.edu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Clinical(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, id=None, name=None, tags=None, category=None, status=None, photo_urls=None):
        """
        Clinical - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'int',
            'name': 'str',
            'tags': 'list[Tag]',
            'category': 'Category',
            'status': 'str',
            'photo_urls': 'list[str]'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'tags': 'tags',
            'category': 'category',
            'status': 'status',
            'photo_urls': 'photoUrls'
        }

        self._id = id
        self._name = name
        self._tags = tags
        self._category = category
        self._status = status
        self._photo_urls = photo_urls

    @property
    def id(self):
        """
        Gets the id of this Clinical.

        :return: The id of this Clinical.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Clinical.

        :param id: The id of this Clinical.
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Clinical.

        :return: The name of this Clinical.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Clinical.

        :param name: The name of this Clinical.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def tags(self):
        """
        Gets the tags of this Clinical.

        :return: The tags of this Clinical.
        :rtype: list[Tag]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """
        Sets the tags of this Clinical.

        :param tags: The tags of this Clinical.
        :type: list[Tag]
        """

        self._tags = tags

    @property
    def category(self):
        """
        Gets the category of this Clinical.

        :return: The category of this Clinical.
        :rtype: Category
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this Clinical.

        :param category: The category of this Clinical.
        :type: Category
        """

        self._category = category

    @property
    def status(self):
        """
        Gets the status of this Clinical.
        Clinical

        :return: The status of this Clinical.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Clinical.
        Clinical

        :param status: The status of this Clinical.
        :type: str
        """
        allowed_values = ["available", "pending", "sold"]
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def photo_urls(self):
        """
        Gets the photo_urls of this Clinical.

        :return: The photo_urls of this Clinical.
        :rtype: list[str]
        """
        return self._photo_urls

    @photo_urls.setter
    def photo_urls(self, photo_urls):
        """
        Sets the photo_urls of this Clinical.

        :param photo_urls: The photo_urls of this Clinical.
        :type: list[str]
        """
        if photo_urls is None:
            raise ValueError("Invalid value for `photo_urls`, must not be `None`")

        self._photo_urls = photo_urls

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Clinical):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Environmental Exposures API

    Environmental Exposures API

    OpenAPI spec version: 1.0.0
    Contact: stealey@renci.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class ExposureType(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, exposure_type=None, description=None, units=None, has_values=None, has_scores=None, schema_version=None):
        """
        ExposureType - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'exposure_type': 'str',
            'description': 'str',
            'units': 'str',
            'has_values': 'bool',
            'has_scores': 'bool',
            'schema_version': 'str'
        }

        self.attribute_map = {
            'exposure_type': 'exposure_type',
            'description': 'description',
            'units': 'units',
            'has_values': 'has_values',
            'has_scores': 'has_scores',
            'schema_version': 'schema_version'
        }

        self._exposure_type = exposure_type
        self._description = description
        self._units = units
        self._has_values = has_values
        self._has_scores = has_scores
        self._schema_version = schema_version


    @property
    def exposure_type(self):
        """
        Gets the exposure_type of this ExposureType.


        :return: The exposure_type of this ExposureType.
        :rtype: str
        """
        return self._exposure_type

    @exposure_type.setter
    def exposure_type(self, exposure_type):
        """
        Sets the exposure_type of this ExposureType.


        :param exposure_type: The exposure_type of this ExposureType.
        :type: str
        """

        self._exposure_type = exposure_type

    @property
    def description(self):
        """
        Gets the description of this ExposureType.


        :return: The description of this ExposureType.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ExposureType.


        :param description: The description of this ExposureType.
        :type: str
        """

        self._description = description

    @property
    def units(self):
        """
        Gets the units of this ExposureType.


        :return: The units of this ExposureType.
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """
        Sets the units of this ExposureType.


        :param units: The units of this ExposureType.
        :type: str
        """

        self._units = units

    @property
    def has_values(self):
        """
        Gets the has_values of this ExposureType.


        :return: The has_values of this ExposureType.
        :rtype: bool
        """
        return self._has_values

    @has_values.setter
    def has_values(self, has_values):
        """
        Sets the has_values of this ExposureType.


        :param has_values: The has_values of this ExposureType.
        :type: bool
        """

        self._has_values = has_values

    @property
    def has_scores(self):
        """
        Gets the has_scores of this ExposureType.


        :return: The has_scores of this ExposureType.
        :rtype: bool
        """
        return self._has_scores

    @has_scores.setter
    def has_scores(self, has_scores):
        """
        Sets the has_scores of this ExposureType.


        :param has_scores: The has_scores of this ExposureType.
        :type: bool
        """

        self._has_scores = has_scores

    @property
    def schema_version(self):
        """
        Gets the schema_version of this ExposureType.


        :return: The schema_version of this ExposureType.
        :rtype: str
        """
        return self._schema_version

    @schema_version.setter
    def schema_version(self, schema_version):
        """
        Sets the schema_version of this ExposureType.


        :param schema_version: The schema_version of this ExposureType.
        :type: str
        """

        self._schema_version = schema_version

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from distutils.core import setup 
setup(
      name = 'greentranslator',
      packages = [ 'greentranslator' ], # this must be the same as the name above
      package_dir={ 'greentranslator' : 'greentranslator' },
      package_data={ 'greentranslator' : [
         'query/*.sparql',
         'exposures_api_client/*',
         'exposures_api_client/models/*',
         'exposures_api_client/apis/*',
         'clinical_api_client/*',
         'clinical_api_client/models/*',
         'clinical_api_client/apis/*'
      ]},
      version = '0.35',
      description = 'Green Team BioMedical Data Translator',
      author = 'Steve Cox',
      author_email = 'scox@renci.org',
      install_requires = [
         'certifi >= 14.05.14',
         'six == 1.10.0',
         'python_dateutil >= 2.5.3',
         'setuptools >= 21.0.0',
         'urllib3 >= 1.15.1',
         'bokeh==0.12.5',
         'numpy==1.12.1',
         'pandas==0.19.2',
         'prov==1.5.0',
         'pydotplus==2.0.2',
         'seaborn==0.7.1',
         'SPARQLWrapper==1.8.0'
      ],
      include_package_data=True,
      url = 'https://github.com/stevencox/greentranslator.git',
      download_url = 'https://github.com/stevencox/greentranslator/archive/0.35.tar.gz',
      keywords = [ 'biomedical', 'environmental', 'exposure', 'clinical' ],
      classifiers = [ ],
    )



# coding: utf-8

"""
    Green Team Clinical API

    The Green Team’s Clinical Data Service API provides defined access to clinical data on ~16,000 ‘HuSH+’ patients with an ‘asthma-like’ phenotype. Users can select input parameters, and the service returns select output based on the input parameters. The input parameters are: age; sex; race; type of visit; and specific ICD and CPT codes1. Based on the input parameters, the service returns the following outpatient parameters: (1) a list of patient IDs and dates of ED and outpatient visits over the 12-month period after diagnosis; and (2) a list of medications prescribed over the 12-month period after diagnosis. The output data are stratified by patients with ≤2 or >2 ED visits over the 12-month period after diagnosis—the primary clinical endpoint used to define, respectively, patients who are ‘responsive’ and ‘non-responsive’ to treatment.

    OpenAPI spec version: 0.0.1
    Contact: champioj@email.unc.edu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into sdk package
from .models.category import Category
from .models.clinical import Clinical
from .models.tag import Tag

# import apis into sdk package
from .apis.clinical_api import ClinicalApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()
